@@ -35,7 +35,6 @@ class Bag(dict):
         self.tmpbag = tmpbag
         self.revbag = revbag
         self.searchbag = searchbag
-        self.order = []
         self.store = None
 
     def _tiddler_key(self, tiddler):
@@ -83,9 +82,7 @@ class Bag(dict):
         a tiddler of the same name in the bag.
         """
         tiddler = self._tiddler_copy(tiddler)
-        if self._tiddler_key(tiddler) in self.order:
-            self.order.remove(self._tiddler_key(tiddler))
-        self.order.append(self._tiddler_key(tiddler))
+        tiddler_key = self._tiddler_key(tiddler)
         self.__setitem__(tiddler)
 
     def add_tiddlers(self, tiddlers):
@@ -100,8 +97,6 @@ class Bag(dict):
         """
         Remove the provided tiddler from the bag.
         """
-        if self._tiddler_key(tiddler) in self.order:
-            self.order.remove(self._tiddler_key(tiddler))
         self.__delitem__(tiddler)
 
     def list_tiddlers(self):
@@ -109,4 +104,4 @@ class Bag(dict):
         List all the tiddlers in the bag, in the order
         they were added.
         """
-        return [self.get(keyword, None) for keyword in self.order]
+        return self.values()
