@@ -7,6 +7,8 @@ cgi.py users (dictionary of lists).
 
 import cgi
 
+from tiddlyweb.filters import parse_for_filters
+
 
 class Query(object):
     """
@@ -34,5 +36,6 @@ class Query(object):
             content = environ['wsgi.input'].read(int(length))
             posted_data = cgi.parse_qs(content)
             environ['tiddlyweb.query'].update(posted_data)
-        environ['tiddlyweb.query'].update(cgi.parse_qs(
-            environ.get('QUERY_STRING', '')))
+        filters, leftovers = parse_for_filters(environ.get('QUERY_STRING', ''))
+        environ['tiddlyweb.query'].update(cgi.parse_qs(leftovers))
+        environ['tiddlyweb.filters'] = filters
